Class: Google::Cloud::VisionAI::V1::AttributeValue

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/visionai/v1/lva.rb

Overview

Represents an actual value of an operator attribute.

Instance Attribute Summary collapse

Instance Attribute Details

#b::Boolean

Returns bool.

Note: The following fields are mutually exclusive: b, i, f, s. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Boolean)

    bool.

    Note: The following fields are mutually exclusive: b, i, f, s. If a field in that set is populated, all other fields in the set will automatically be cleared.



180
181
182
183
# File 'proto_docs/google/cloud/visionai/v1/lva.rb', line 180

class AttributeValue
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#f::Float

Returns float.

Note: The following fields are mutually exclusive: f, i, b, s. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Float)

    float.

    Note: The following fields are mutually exclusive: f, i, b, s. If a field in that set is populated, all other fields in the set will automatically be cleared.



180
181
182
183
# File 'proto_docs/google/cloud/visionai/v1/lva.rb', line 180

class AttributeValue
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#i::Integer

Returns int.

Note: The following fields are mutually exclusive: i, f, b, s. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Integer)

    int.

    Note: The following fields are mutually exclusive: i, f, b, s. If a field in that set is populated, all other fields in the set will automatically be cleared.



180
181
182
183
# File 'proto_docs/google/cloud/visionai/v1/lva.rb', line 180

class AttributeValue
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#s::String

Returns string.

Note: The following fields are mutually exclusive: s, i, f, b. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::String)

    string.

    Note: The following fields are mutually exclusive: s, i, f, b. If a field in that set is populated, all other fields in the set will automatically be cleared.



180
181
182
183
# File 'proto_docs/google/cloud/visionai/v1/lva.rb', line 180

class AttributeValue
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end