Class: Google::Cloud::VisionAI::V1::CreateProcessRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/visionai/v1/lva_service.rb

Overview

Message for creating a Process.

Instance Attribute Summary collapse

Instance Attribute Details

#parent::String

Returns Required. Value for parent.

Returns:

  • (::String)

    Required. Value for parent.



357
358
359
360
# File 'proto_docs/google/cloud/visionai/v1/lva_service.rb', line 357

class CreateProcessRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#process::Google::Cloud::VisionAI::V1::Process

Returns Required. The resource being created.

Returns:



357
358
359
360
# File 'proto_docs/google/cloud/visionai/v1/lva_service.rb', line 357

class CreateProcessRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#process_id::String

Returns Required. Id of the requesting object.

Returns:

  • (::String)

    Required. Id of the requesting object.



357
358
359
360
# File 'proto_docs/google/cloud/visionai/v1/lva_service.rb', line 357

class CreateProcessRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#request_id::String

Returns Optional. An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. The server will guarantee that for at least 60 minutes since the first request.

For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.

The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).

Returns:

  • (::String)

    Optional. An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. The server will guarantee that for at least 60 minutes since the first request.

    For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.

    The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).



357
358
359
360
# File 'proto_docs/google/cloud/visionai/v1/lva_service.rb', line 357

class CreateProcessRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end