Class: Google::Cloud::VisionAI::V1::FacetBucket

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/visionai/v1/warehouse.rb

Overview

Holds the facet value, selections state, and metadata.

Defined Under Namespace

Classes: Range

Instance Attribute Summary collapse

Instance Attribute Details

#range::Google::Cloud::VisionAI::V1::FacetBucket::Range

Returns Range value.

Note: The following fields are mutually exclusive: range, value. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:



2468
2469
2470
2471
2472
2473
2474
2475
2476
2477
2478
2479
2480
2481
2482
2483
# File 'proto_docs/google/cloud/visionai/v1/warehouse.rb', line 2468

class FacetBucket
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The range of values [start, end) for which faceting is applied.
  # @!attribute [rw] start
  #   @return [::Google::Cloud::VisionAI::V1::FacetValue]
  #     Start of the range. Non-existence indicates some bound (e.g. -inf).
  # @!attribute [rw] end
  #   @return [::Google::Cloud::VisionAI::V1::FacetValue]
  #     End of the range. Non-existence indicates some bound (e.g. inf).
  class Range
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#selected::Boolean

Returns Whether one facet bucket is selected. This field represents user's facet selection. It is set by frontend in SearchVideosRequest.

Returns:

  • (::Boolean)

    Whether one facet bucket is selected. This field represents user's facet selection. It is set by frontend in SearchVideosRequest.



2468
2469
2470
2471
2472
2473
2474
2475
2476
2477
2478
2479
2480
2481
2482
2483
# File 'proto_docs/google/cloud/visionai/v1/warehouse.rb', line 2468

class FacetBucket
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The range of values [start, end) for which faceting is applied.
  # @!attribute [rw] start
  #   @return [::Google::Cloud::VisionAI::V1::FacetValue]
  #     Start of the range. Non-existence indicates some bound (e.g. -inf).
  # @!attribute [rw] end
  #   @return [::Google::Cloud::VisionAI::V1::FacetValue]
  #     End of the range. Non-existence indicates some bound (e.g. inf).
  class Range
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#value::Google::Cloud::VisionAI::V1::FacetValue

Returns Singular value.

Note: The following fields are mutually exclusive: value, range. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::VisionAI::V1::FacetValue)

    Singular value.

    Note: The following fields are mutually exclusive: value, range. If a field in that set is populated, all other fields in the set will automatically be cleared.



2468
2469
2470
2471
2472
2473
2474
2475
2476
2477
2478
2479
2480
2481
2482
2483
# File 'proto_docs/google/cloud/visionai/v1/warehouse.rb', line 2468

class FacetBucket
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The range of values [start, end) for which faceting is applied.
  # @!attribute [rw] start
  #   @return [::Google::Cloud::VisionAI::V1::FacetValue]
  #     Start of the range. Non-existence indicates some bound (e.g. -inf).
  # @!attribute [rw] end
  #   @return [::Google::Cloud::VisionAI::V1::FacetValue]
  #     End of the range. Non-existence indicates some bound (e.g. inf).
  class Range
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end