Class: Google::Cloud::VisionAI::V1::Instance::InputResource

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/visionai/v1/platform.rb

Overview

Message of input resource used in one application instance.

Instance Attribute Summary collapse

Instance Attribute Details

#annotated_stream::Google::Cloud::VisionAI::V1::StreamWithAnnotation

Deprecated.

This field is deprecated and may be removed in the next major version update.

Returns If the input resource is VisionAI Stream, the associated annotations can be specified using annotated_stream instead.

Note: The following fields are mutually exclusive: annotated_stream, input_resource. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::VisionAI::V1::StreamWithAnnotation)

    If the input resource is VisionAI Stream, the associated annotations can be specified using annotated_stream instead.

    Note: The following fields are mutually exclusive: annotated_stream, input_resource. If a field in that set is populated, all other fields in the set will automatically be cleared.



1154
1155
1156
1157
# File 'proto_docs/google/cloud/visionai/v1/platform.rb', line 1154

class InputResource
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#annotations::Google::Cloud::VisionAI::V1::ResourceAnnotations

Returns Contains resource annotations.

Returns:



1154
1155
1156
1157
# File 'proto_docs/google/cloud/visionai/v1/platform.rb', line 1154

class InputResource
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#consumer_node::String

Returns The name of graph node who receives the input resource. For example: input_resource: visionai.googleapis.com/v1/projects/123/locations/us-central1/clusters/456/streams/input-stream-a consumer_node: stream-input.

Returns:

  • (::String)

    The name of graph node who receives the input resource. For example: input_resource: visionai.googleapis.com/v1/projects/123/locations/us-central1/clusters/456/streams/input-stream-a consumer_node: stream-input



1154
1155
1156
1157
# File 'proto_docs/google/cloud/visionai/v1/platform.rb', line 1154

class InputResource
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#data_type::Google::Cloud::VisionAI::V1::DataType

Returns Data type for the current input resource.

Returns:



1154
1155
1156
1157
# File 'proto_docs/google/cloud/visionai/v1/platform.rb', line 1154

class InputResource
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#input_resource::String

Returns The direct input resource name. If the instance type is STREAMING_PREDICTION, the input resource is in format of "projects/123/locations/us-central1/clusters/456/streams/stream-a". If the instance type is BATCH_PREDICTION from Cloud Storage input container, the input resource is in format of "gs://bucket-a".

Note: The following fields are mutually exclusive: input_resource, annotated_stream. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::String)

    The direct input resource name. If the instance type is STREAMING_PREDICTION, the input resource is in format of "projects/123/locations/us-central1/clusters/456/streams/stream-a". If the instance type is BATCH_PREDICTION from Cloud Storage input container, the input resource is in format of "gs://bucket-a".

    Note: The following fields are mutually exclusive: input_resource, annotated_stream. If a field in that set is populated, all other fields in the set will automatically be cleared.



1154
1155
1156
1157
# File 'proto_docs/google/cloud/visionai/v1/platform.rb', line 1154

class InputResource
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#input_resource_binding::String

Returns The specific input resource binding which will consume the current Input Resource, can be ignored is there is only 1 input binding.

Returns:

  • (::String)

    The specific input resource binding which will consume the current Input Resource, can be ignored is there is only 1 input binding.



1154
1155
1156
1157
# File 'proto_docs/google/cloud/visionai/v1/platform.rb', line 1154

class InputResource
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end