Class: Google::Cloud::VisionAI::V1::VideoClassificationPredictionResult::IdentifiedClassification

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/visionai/v1/annotations.rb

Overview

Each IdentifiedClassification is one particular identification of an classification specified with the AnnotationSpec id and display_name, and the associated confidence score.

Instance Attribute Summary collapse

Instance Attribute Details

#confidence::Float

Returns The Model's confidence in correction of this identification, higher value means higher confidence.

Returns:

  • (::Float)

    The Model's confidence in correction of this identification, higher value means higher confidence.



411
412
413
414
# File 'proto_docs/google/cloud/visionai/v1/annotations.rb', line 411

class IdentifiedClassification
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#display_name::String

Returns The display name of the AnnotationSpec that had been identified.

Returns:

  • (::String)

    The display name of the AnnotationSpec that had been identified.



411
412
413
414
# File 'proto_docs/google/cloud/visionai/v1/annotations.rb', line 411

class IdentifiedClassification
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#id::String

Returns The resource ID of the AnnotationSpec that had been identified.

Returns:

  • (::String)

    The resource ID of the AnnotationSpec that had been identified.



411
412
413
414
# File 'proto_docs/google/cloud/visionai/v1/annotations.rb', line 411

class IdentifiedClassification
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end